searchData={"items":[{"type":"module","title":"Forex","doc":"`Forex` is a simple Elixir library that serves as a wrapper to the\nforeign exchange reference rates provided by the European Central Bank.\n\n>","ref":"Forex.html"},{"type":"module","title":"From the [European Central Bank](https://www.ecb.europa.eu/stats/policy_and_exchange_rates/euro_reference_exchange_rates/html/index.en.html) {: .info} - Forex","doc":">\n> The reference rates are usually updated at around **16:00 CET** every working day, except on\n> [TARGET closing days](https://www.ecb.europa.eu/ecb/contacts/working-hours/html/index.en.html).\n>\n> They are based on the daily concertation procedure between central banks across Europe,\n> which normally takes place around 14:10 CET. The reference rates are published for\n> information purposes only. Using the rates for transaction\n> purposes is _strongly discouraged_.","ref":"Forex.html#module-from-the-european-central-bank-https-www-ecb-europa-eu-stats-policy_and_exchange_rates-euro_reference_exchange_rates-html-index-en-html-info"},{"type":"module","title":"Motivation - Forex","doc":"Even though there are other libraries in the Elixir ecosystem that provide\nsimilar functionality (example: `ex_money`), `Forex` was created with the intent\nof providing access to currency exchange rates for projects that want to self-host\nthe data and not rely on third-party paid services in a simple and straightforward\nmanner. No API keys, no authentication, no rate limits, just a simple Elixir library\nthat fetches the data from the European Central Bank and caches it for later use.","ref":"Forex.html#module-motivation"},{"type":"module","title":"Options - Forex","doc":"* `:base` - The base currency to convert the rates to. The default currency base is `:eur`.\n\n* `:format` - The format of the rate value. Supported values are `:decimal` and `:string`.\n  The default is `:decimal`.\n\n* `:round` - The number of decimal places to round the rate value to. The default is `5`.\n\n* `:symbols` - A list of currency codes (atoms or strings) to filter the rates by.\n  The default is `nil`, which means all available currencies will be returned.\n\n* `:keys` - The format of the keys in the rate map. Supported values are `:strings` and `:atoms`.\n  The default is `:atoms`.\n\n* `:use_cache` - A boolean value to enable or disable the cache. To enable the cache check the\n  usage section docs for detailed instructions. The default is `true`.\n\n* `:feed_fn` - An `mfa` tuple that can be used to fetch the exchange rates from a custom feed.\n  This option is mostly used for testing purposes. The default is `nil`, which means the\n  default feed will be used.","ref":"Forex.html#module-options"},{"type":"module","title":"Usage - Forex","doc":"By default the `base` currency is the Euro (EUR), the same as the European Central Bank,\nbut you change the base currency by passing the `base` option to the relevant functions.\n\nTo fetch the latest exchange rates, you can use the `current_rates/1` function:\n\n```elixir\niex> Forex.current_rates()\n{:ok,\n  %{\n    base: :eur,\n    date: ~D[2025-03-12],\n    rates: %{\n      usd: Decimal.new(\"1.1234\"),\n      jpy: Decimal.new(\"120.1234\"),\n      ...\n      zar: Decimal.new(\"24.1442\")\n    }}\n  }\n```\n\nTo fetch the exchange rates for the last ninety days, you can use the `last_ninety_days_rates/1` function:\n\n```elixir\niex> Forex.last_ninety_days_rates()\n{:ok,\n  [\n    %{\n      date: ~D[2025-03-12],\n      base: :eur,\n      rates: %{\n        usd: Decimal.new(\"1.1234\"),\n        jpy: Decimal.new(\"120.1234\"),\n        ...\n        zar: Decimal.new(\"24.1442\")\n      }\n    },\n    ...\n  ]}\n```\n\nTo fetch the historic exchange rates (for any working day since 4 January 1999),\nyou can use the `historic_rates/1` function:\n\n```elixir\niex> Forex.historic_rates()\n{:ok,\n  [\n    %{\n      date: ~D[2025-03-12],\n      base: :eur,\n      rates: %{\n        usd: Decimal.new(\"1.1234\"),\n        jpy: Decimal.new(\"120.1234\"),\n        ...\n        zar: Decimal.new(\"24.1442\")\n      }\n    },\n    ...\n  ]}\n```\n\nTo fetch the exchange rates for a specific date, you can use the `get_historic_rate/2` function:\n\n```elixir\niex> Forex.get_historic_rate(~D[2025-02-25])\n{:ok,\n  [\n    %{\n      date: ~D[2025-03-12],\n      base: :eur,\n      rates: %{\n        usd: Decimal.new(\"1.1234\"),\n        jpy: Decimal.new(\"120.1234\"),\n        ...\n        zar: Decimal.new(\"24.1442\")\n      }\n    },\n    ...\n  ]}\n```\n\nTo fetch the exchange rates between two dates, you can use the `get_historic_rates_between/3` function:\n\n```elixir\niex> Forex.get_historic_rates_between(~D[2025-02-25], ~D[2025-02-28])\n\n{:ok,\n  [\n    %{\n      date: ~D[2025-03-12],\n      base: :eur,\n      rates: %{\n        usd: Decimal.new(\"1.1234\"),\n        jpy: Decimal.new(\"120.1234\"),\n        ...\n        zar: Decimal.new(\"24.1442\")\n      }\n    },\n    ...\n  ]}\n```\n\nTo convert an amount from one currency to another, you can use the `exchange/4` function:\n\n```elixir\niex> Forex.exchange(100, \"USD\", \"EUR\")\n{:ok, Decimal.new(\"91.86100\")}\n\niex>  Forex.exchange(420, :eur, :gbp)\n{:ok, Decimal.new(\"353.12760\")}\n```\n\nTo list all available currencies from the European Central Bank,\nyou can use the `available_currencies/1` function:\n\n```elixir\niex> Forex.available_currencies()\n[:try, :eur, :aud, :bgn, :brl, ...]\n```","ref":"Forex.html#module-usage"},{"type":"module","title":"Mix Tasks - Forex","doc":"The `Forex` library also provides mix tasks to export the exchange rates\nto a JSON file. You can use the following tasks:\n* `mix forex.export.current` - Export the current rates to a JSON file.\n* `mix forex.export.historic` - Export the historic rates to a JSON file.\n* `mix forex.export.ninety` - Export the last ninety days rates to a JSON file.\n\nThe tasks accept some options to customize the output:\n\n* `--base`      - The base currency to use. Defaults to `EUR`.\n* `--symbols`   - The currencies to fetch. Defaults to all currencies.\n* `--output`    - The output directory. Defaults to `priv/data/forex`.\n* `--help`      - Show this help message.\n\nFor example the task `mix forex.export.current --base USD --symbols EUR,USD,GBP`\nwill export the current exchange rates for EUR, USD and GBP to a `current_rates.json`\nJSON file in the `priv/data/forex` directory with the base currency set to USD.","ref":"Forex.html#module-mix-tasks"},{"type":"function","title":"Forex.available_currencies/1","doc":"Return a list of all available currencies ISO 4217 codes.","ref":"Forex.html#available_currencies/1"},{"type":"function","title":"Forex.base_currency_rate/0","doc":"","ref":"Forex.html#base_currency_rate/0"},{"type":"type","title":"Forex.currency_code/0","doc":"The currency code is a three-letter code that represents a currency,\nin accordance with the ISO 4217 standard.\nIt can be either a string or an atom.","ref":"Forex.html#t:currency_code/0"},{"type":"function","title":"Forex.currency_options/1","doc":"Return a list of all available currencies in the format\n`%{currency_code() => currency_name()}`.\nUseful for input forms, selects, etc.","ref":"Forex.html#currency_options/1"},{"type":"function","title":"Forex.current_rates/1","doc":"Fetch the latest exchange rates from the European Central Bank (ECB).","ref":"Forex.html#current_rates/1"},{"type":"function","title":"Return Value - Forex.current_rates/1","doc":"Returns `{:ok, %{base: atom(), date: Date.t(), rates: map()}}` on success where:\n- `base` is the base currency code\n- `date` is the reference date\n- `rates` is a map of currency codes to rate values","ref":"Forex.html#current_rates/1-return-value"},{"type":"function","title":"Arguments - Forex.current_rates/1","doc":"* `opts` - Options:\n  * `:format` - Format of rates (`:decimal` or `:string`, default: `:decimal`)\n  * `:base` - Base currency (default: `EUR`)\n  * `:symbols` - List of currency codes to include\n  * `:keys` - Key format in rates map (`:atoms` or `:strings`)\n  * `:use_cache` - Whether to use cached rates (default: `true`)","ref":"Forex.html#current_rates/1-arguments"},{"type":"function","title":"Examples - Forex.current_rates/1","doc":"```elixir\n{:ok, %{base: :eur, date: ~D[2025-03-12], rates: %{usd: Decimal.new(\"1.1234\"), jpy: Decimal.new(\"120.1234\"), ...}}}\n```","ref":"Forex.html#current_rates/1-examples"},{"type":"function","title":"Forex.current_rates!/1","doc":"Same as `current_rates/1`, but raises an error if the request fails.","ref":"Forex.html#current_rates!/1"},{"type":"function","title":"Forex.exchange/4","doc":"Exchange a given amount from one currency to another.\nIt will use the cached exchange rates from the European Central\nBank (ECB) or fetch the latest rates if the cache is disabled.","ref":"Forex.html#exchange/4"},{"type":"function","title":"Options - Forex.exchange/4","doc":"* `:format` - The format of the rate value. Supported values are `:decimal` and `:string`. The default is `:decimal`.\n* `:round` - The number of decimal places to round the rate value to. The default is `4`.","ref":"Forex.html#exchange/4-options"},{"type":"function","title":"Examples - Forex.exchange/4","doc":"```elixir\niex> Forex.exchange(100, \"USD\", \"EUR\")\n{:ok, Decimal.new(\"91.86100\")}\n\niex> Forex.exchange(420, :eur, :gbp, format: :string)\n{:ok, \"353.12760\"}\n\niex> Forex.exchange(123, :gbp, :usd, format: :string, round: 1)\n{:ok, \"159.3\"}\n```","ref":"Forex.html#exchange/4-examples"},{"type":"function","title":"Forex.exchange!/4","doc":"Same as `exchange/3`, but raises an error if the request fails.","ref":"Forex.html#exchange!/4"},{"type":"function","title":"Forex.get_currency/1","doc":"Get the currency information for the given ISO code.","ref":"Forex.html#get_currency/1"},{"type":"function","title":"Forex.get_currency!/1","doc":"Get the currency information for the given ISO code.\nLike `get_currency/1`, but raises an error if the currency is not found.","ref":"Forex.html#get_currency!/1"},{"type":"function","title":"Forex.get_historic_rate/2","doc":"Get a specific date from the historic exchange rates feed.\nIt returns either an `{:ok, rate()}` if the rate was successfully\nretrieved or an `{:error, reasons}` if the rate was not found.","ref":"Forex.html#get_historic_rate/2"},{"type":"function","title":"Arguments - Forex.get_historic_rate/2","doc":"* `date` - The date to get the rate for. `date` is either a `Date.new()` struct\n  or a string in the ISO 8601 format.\n* `opts` - Same options as `current_rates/1`.","ref":"Forex.html#get_historic_rate/2-arguments"},{"type":"function","title":"Forex.get_historic_rate!/2","doc":"Same as `get_historic_rate/2`, but raises an error if the request fails.","ref":"Forex.html#get_historic_rate!/2"},{"type":"function","title":"Forex.get_historic_rates_between/3","doc":"Get exchange rates between two dates from the historic exchange rates feed.\n\nReturns a list of exchange rates for each working day between the start and end date.","ref":"Forex.html#get_historic_rates_between/3"},{"type":"function","title":"Arguments - Forex.get_historic_rates_between/3","doc":"* `start_date` - Start date (Date, ISO 8601 string, or {year, month, day} tuple)\n* `end_date` - End date (Date, ISO 8601 string, or {year, month, day} tuple)\n* `opts` - Same options as `current_rates/1`","ref":"Forex.html#get_historic_rates_between/3-arguments"},{"type":"function","title":"Return Value - Forex.get_historic_rates_between/3","doc":"Returns `{:ok, [%{date: Date.t(), base: atom(), rates: map()}]}` where each list item\nrepresents rates for one day.","ref":"Forex.html#get_historic_rates_between/3-return-value"},{"type":"function","title":"Examples - Forex.get_historic_rates_between/3","doc":"```elixir\niex> Forex.get_historic_rates_between(\"2023-01-01\", \"2023-01-05\")\n{:ok, [\n  %{date: ~D[2023-01-02], base: :eur, rates: %{usd: Decimal.new(\"1.0678\", ...}},\n  %{date: ~D[2023-01-03], base: :eur, rates: %{usd: Decimal.new(\"1.0545\", ...}},\n  %{date: ~D[2023-01-04], base: :eur, rates: %{usd: Decimal.new(\"1.0599\", ...}},\n  %{date: ~D[2023-01-05], base: :eur, rates: %{usd: Decimal.new(\"1.0556\", ...}}\n]}\n```","ref":"Forex.html#get_historic_rates_between/3-examples"},{"type":"function","title":"Forex.get_historic_rates_between!/3","doc":"Same as `get_historic_rates_between/3`, but raises an error if the request fails.","ref":"Forex.html#get_historic_rates_between!/3"},{"type":"function","title":"Forex.historic_rates/1","doc":"Fetch the historic exchange rates feed from the European\nCentral Bank (ECB) for any working day since 4 January 1999.\n\nBy default, the historic rates are not automatically fetched when using\nthe Fetcher (scheduler) module, since the whole file is returned this avoids excessive memory\nusage when caching the results if not needed. To fetch and cache the historic rates,\nyou need to manually call this function.\n\nSame options as `current_rates/1`.","ref":"Forex.html#historic_rates/1"},{"type":"function","title":"Forex.historic_rates!/1","doc":"Same as `historic_rates/1`, but raises an error if the request fails.","ref":"Forex.html#historic_rates!/1"},{"type":"function","title":"Forex.json_library/0","doc":"Returns the configured JSON encoding library for Forex.\nThe default is the `Jason` library.\n\nThe JSON library must implement the `encode/1` function.\n\nThe JSON library is only required when using the mix tasks\nto export the exchange rates to a JSON file, otherwise this\nsetting can be ignored.\n\nTo customize the JSON library, including the following\nin your `config/config.exs`:\n\n    config :forex, :json_library, AlternativeJsonLibrary\n\nThe library must implement the `encode_to_iodata!/2` function.","ref":"Forex.html#json_library/0"},{"type":"function","title":"Forex.last_ninety_days_rates/1","doc":"Fetch the exchange rates for the last ninety days\nfrom the European Central Bank (ECB).\n\nNote that rates are only available on working days.","ref":"Forex.html#last_ninety_days_rates/1"},{"type":"function","title":"Arguments - Forex.last_ninety_days_rates/1","doc":"Same options as `current_rates/1`.","ref":"Forex.html#last_ninety_days_rates/1-arguments"},{"type":"function","title":"Forex.last_ninety_days_rates!/1","doc":"Same as `last_ninety_days_rates/1`, but raises an error if the request fails.","ref":"Forex.html#last_ninety_days_rates!/1"},{"type":"function","title":"Forex.last_updated/0","doc":"Last updated date of the exchange rates feed.\nLists the last date the exchange rates were updated from the cache.\n\nExample:\n\n    iex> Forex.last_updated()\n    [\n      current_rates: ~U[2024-11-23 18:19:38.974337Z],\n      historic_rates: ~U[2024-11-23 18:27:07.391035Z],\n      last_ninety_days_rates: ~U[2024-11-23 18:19:39.111818Z],\n    ]","ref":"Forex.html#last_updated/0"},{"type":"function","title":"Forex.list_currencies/1","doc":"Return a list of all available currencies.","ref":"Forex.html#list_currencies/1"},{"type":"function","title":"Forex.options/1","doc":"Validate and return the options for the Forex module functions,\nusing default values if the options are not provided.","ref":"Forex.html#options/1"},{"type":"function","title":"Options - Forex.options/1","doc":"* `:base` - The base currency to convert rates to (default: `:eur`)\n* `:format` - Format of rate values (`:decimal` or `:string`, default: `:decimal`)\n* `:round` - Decimal places for rounding (default: `5`)\n* `:symbols` - Currency codes to include (default: `nil` for all currencies)\n* `:keys` - Map key format (`:atoms` or `:strings`, default: `:atoms`)\n* `:use_cache` - Whether to use cached rates (default: `true`)\n* `:feed_fn` - Optional custom feed function as `{module, function, args}` (default: `nil`)","ref":"Forex.html#options/1-options"},{"type":"type","title":"Forex.rate/0","doc":"A currency rate, represented as a map with the currency code as the key\nand the rate as the value. The rate can be either a Decimal or a string.","ref":"Forex.html#t:rate/0"},{"type":"behaviour","title":"Forex.Cache","doc":"Since the ECB reference rates are usually updated at around 16:00 CET\nevery working day we should cache the response.\n\nThis module defines a simple caching layer behaviour to cache the\nresponses from the `Forex.Feed` module.\n\nThe default implementation uses ETS as the cache storage.\nYou can override the cache module by setting the `:cache_module` configuration\noption in the `Forex.Fetcher` module options.","ref":"Forex.Cache.html"},{"type":"function","title":"Forex.Cache.cache_mod/0","doc":"","ref":"Forex.Cache.html#cache_mod/0"},{"type":"function","title":"Forex.Cache.current_rates/0","doc":"","ref":"Forex.Cache.html#current_rates/0"},{"type":"function","title":"Forex.Cache.delete/1","doc":"","ref":"Forex.Cache.html#delete/1"},{"type":"callback","title":"Forex.Cache.delete/1","doc":"Delete an entry from the cache with the given `key`.","ref":"Forex.Cache.html#c:delete/1"},{"type":"callback","title":"Forex.Cache.get/2","doc":"Get the cache entry with the given `key`.\nReturns `nil` if the entry does not exist.","ref":"Forex.Cache.html#c:get/2"},{"type":"function","title":"Forex.Cache.historic_rates/0","doc":"","ref":"Forex.Cache.html#historic_rates/0"},{"type":"function","title":"Forex.Cache.init/0","doc":"","ref":"Forex.Cache.html#init/0"},{"type":"callback","title":"Forex.Cache.init/0","doc":"Inits the cache.","ref":"Forex.Cache.html#c:init/0"},{"type":"function","title":"Forex.Cache.initialized?/0","doc":"","ref":"Forex.Cache.html#initialized?/0"},{"type":"callback","title":"Forex.Cache.initialized?/0","doc":"Check if the cache is initialized.","ref":"Forex.Cache.html#c:initialized?/0"},{"type":"function","title":"Forex.Cache.last_ninety_days_rates/0","doc":"","ref":"Forex.Cache.html#last_ninety_days_rates/0"},{"type":"function","title":"Forex.Cache.last_updated/0","doc":"","ref":"Forex.Cache.html#last_updated/0"},{"type":"callback","title":"Forex.Cache.last_updated/0","doc":"Get a list of all keys in the cache and the respective\nupdated at timestamps.","ref":"Forex.Cache.html#c:last_updated/0"},{"type":"function","title":"Forex.Cache.last_updated/1","doc":"","ref":"Forex.Cache.html#last_updated/1"},{"type":"callback","title":"Forex.Cache.last_updated/1","doc":"Get the latest updated at timestamp for the given `key`.\nReturns `nil` if the entry does not exist.","ref":"Forex.Cache.html#c:last_updated/1"},{"type":"callback","title":"Forex.Cache.put/3","doc":"Put a new entry into the cache with the given `key` and `value`.","ref":"Forex.Cache.html#c:put/3"},{"type":"function","title":"Forex.Cache.reset/0","doc":"","ref":"Forex.Cache.html#reset/0"},{"type":"callback","title":"Forex.Cache.reset/0","doc":"Reset the cache table.","ref":"Forex.Cache.html#c:reset/0"},{"type":"function","title":"Forex.Cache.resolve/3","doc":"","ref":"Forex.Cache.html#resolve/3"},{"type":"callback","title":"Forex.Cache.resolve/3","doc":"Resolve the cache entry with the given `key` using the given `resolver`.\nIf the entry does not exist, the `resolver` function, an mfa tuple, is called and the\nresult is stored in the cache.\n\nExample:\n\n  Forex.Cache.resolve(:current_rates, {Forex.Feed, :fetch_current_rates, []})","ref":"Forex.Cache.html#c:resolve/3"},{"type":"function","title":"Forex.Cache.terminate/0","doc":"","ref":"Forex.Cache.html#terminate/0"},{"type":"callback","title":"Forex.Cache.terminate/0","doc":"Terminate the cache process.","ref":"Forex.Cache.html#c:terminate/0"},{"type":"module","title":"Forex.Cache.DETS","doc":"Implementation of the `Forex.Cache` behaviour using DETS.","ref":"Forex.Cache.DETS.html"},{"type":"module","title":"Forex.Cache.ETS","doc":"Implementation of the `Forex.Cache` behaviour using ETS.","ref":"Forex.Cache.ETS.html"},{"type":"module","title":"Forex.Currency","doc":"This module provides curreny information and utility functions.\n\nOnly a subset of all the currencies are included in this module, since\nthese are the currencies supported by the European Central Bank (ECB)\nexchange rates feed.","ref":"Forex.Currency.html"},{"type":"function","title":"Forex.Currency.all/1","doc":"Get all list of all currencies, including disabled currencies (necessary,\nsince historical rates may include disabled currencies in the past).","ref":"Forex.Currency.html#all/1"},{"type":"function","title":"Forex.Currency.available/1","doc":"Get all list of all the available currencies (enabled currencies), that\nis, all the currencies that are supported by the ECB at the present time.","ref":"Forex.Currency.html#available/1"},{"type":"function","title":"Forex.Currency.disabled/1","doc":"Get all list of all the disabled currencies, that is,\nall the currencies that are not supported by the ECB at the present time but\nmay have been supported in the past and are included in historical rates.","ref":"Forex.Currency.html#disabled/1"},{"type":"function","title":"Forex.Currency.exchange/4","doc":"Exchange a given amount from one currency to another using ECB rates.","ref":"Forex.Currency.html#exchange/4"},{"type":"function","title":"Options - Forex.Currency.exchange/4","doc":"* `:format` - Output format (`:decimal` or `:string`). Defaults to `:decimal`.\n  * `:round` - Decimal places for rounding. Defaults to `5`.","ref":"Forex.Currency.html#exchange/4-options"},{"type":"function","title":"Examples - Forex.Currency.exchange/4","doc":"iex> Forex.exchange(100, :USD, :EUR)\n    {:ok, Decimal.new(\"95.28300\")}\n\n    iex> Forex.exchange(100, \"USD\", \"EUR\", format: :string)\n    {:ok, \"95.28300\"}\n\n    iex> Forex.exchange(100, \"INVALID\", \"EUR\")\n    {:error, :invalid_currency}","ref":"Forex.Currency.html#exchange/4-examples"},{"type":"function","title":"Forex.Currency.exchange!/4","doc":"Exchange a given amount from one currency to another using ECB rates.\nLike `exchange/4`, but raises a `Forex.CurrencyError` if the exchange fails.","ref":"Forex.Currency.html#exchange!/4"},{"type":"function","title":"Forex.Currency.exists?/1","doc":"Check if a currency with the given ISO exists, i.e.,\nif it is supported by the European Central Bank (ECB) service.\n\nExample:\n\n    iex> Forex.Currency.exists?(:eur)\n    true\n    iex> Forex.Currency.exists?(\"USD\")\n    true\n    iex> Forex.Currency.exists?(:GBP)\n    true\n    iex> Forex.Currency.exists?(:xpt)\n    false\n    iex> Forex.Currency.exists?(:invalid)\n    false\n    iex> Forex.Currency.exists?(nil)\n    false","ref":"Forex.Currency.html#exists?/1"},{"type":"function","title":"Forex.Currency.get/1","doc":"Get the currency information for the given ISO code.\n\nExample:\n\n    iex> Forex.Currency.get(:eur)\n    {:ok, %{name: \"Euro\", ...}}\n    iex> Forex.Currency.get(\"USD\")\n    {:ok, %{name: \"United States Dollar\", ...}}\n    iex> Forex.Currency.get(:GBP)\n    {:ok, %{name: \"British Pound Sterling\", ...}}","ref":"Forex.Currency.html#get/1"},{"type":"function","title":"Forex.Currency.get!/1","doc":"Get the currency information for the given ISO code.\nThe same as `get/1`, but raises a `Forex.CurrencyError` if the currency is not found.","ref":"Forex.Currency.html#get!/1"},{"type":"function","title":"Forex.Currency.maybe_rebase/2","doc":"This function is used to rebase the rates to a new base currency.\n\nThe default base currency is `:EUR`, so if the base_currency is a different\ncurrency, the rates will be converted to the new currency base.","ref":"Forex.Currency.html#maybe_rebase/2"},{"type":"function","title":"Forex.Currency.rebase/2","doc":"Given a list of rates in the form of %{currency_code() => Decimal.t()},\nconvert the rates to a new currency base.","ref":"Forex.Currency.html#rebase/2"},{"type":"module","title":"Forex.Feed","doc":"This module is responsible for fetching the latest exchange rates from the\nEuropean Central Bank (ECB) and parsing the XML response.\n\nThe ECB provides three different feeds:\n\n- Current exchange rates: https://www.ecb.europa.eu/stats/eurofxref/eurofxref-daily.xml\n- Exchange rates for the last ninety days: https://www.ecb.europa.eu/stats/eurofxref/eurofxref-hist-90d.xml\n- Historic exchange rates: https://www.ecb.europa.eu/stats/eurofxref/eurofxref-hist.xml\n\nFor each feed, this module provides a function to fetch the rates and parse the response, respectively,\n`current_rates/1`, `last_ninety_days_rates/1`, and `historic_rates/1`.","ref":"Forex.Feed.html"},{"type":"function","title":"Forex.Feed.api_mod/0","doc":"The API module to use for fetching the exchange rates, by default uses the HTTP API.\nThe API module must implement the `Forex.Feed.API` behaviour.\n\nThis is useful for testing purposes, where you can provide a mock API module or\nfor using a different API module, for example, an API module that uses a different\nHTTP client.","ref":"Forex.Feed.html#api_mod/0"},{"type":"function","title":"Forex.Feed.base_url/0","doc":"The base URL for the European Central Bank (ECB) exchange rate feeds.","ref":"Forex.Feed.html#base_url/0"},{"type":"function","title":"Forex.Feed.current_rates/1","doc":"Fetches the latest exchange rates from the European Central Bank (ECB).","ref":"Forex.Feed.html#current_rates/1"},{"type":"function","title":"Forex.Feed.historic_rates/1","doc":"Fetches the historic exchange rates from the European Central Bank (ECB).","ref":"Forex.Feed.html#historic_rates/1"},{"type":"function","title":"Forex.Feed.last_ninety_days_rates/1","doc":"Fetches the exchange rates for the last ninety days from the European Central Bank (ECB).","ref":"Forex.Feed.html#last_ninety_days_rates/1"},{"type":"function","title":"Forex.Feed.path/1","doc":"The path for the different exchange rate feeds, corresponding\nto each different feed provided by the European Central Bank (ECB).","ref":"Forex.Feed.html#path/1"},{"type":"behaviour","title":"Forex.Feed.API","doc":"This module is responsible for defining the behaviour of the feed (HTTP) client.","ref":"Forex.Feed.API.html"},{"type":"callback","title":"Forex.Feed.API.get_current_rates/1","doc":"","ref":"Forex.Feed.API.html#c:get_current_rates/1"},{"type":"callback","title":"Forex.Feed.API.get_historic_rates/1","doc":"","ref":"Forex.Feed.API.html#c:get_historic_rates/1"},{"type":"callback","title":"Forex.Feed.API.get_last_ninety_days_rates/1","doc":"","ref":"Forex.Feed.API.html#c:get_last_ninety_days_rates/1"},{"type":"module","title":"Forex.Feed.API.HTTP","doc":"The default HTTP API module for fetching the exchange rates from the European Central Bank (ECB).\nIt implements the `Forex.Feed.API` behaviour and it uses `Req` as the HTTP client.\n\nTo use a different HTTP client, just set the `:feed_api` configuration option, for example:\n\n    config :forex, feed_api: MyApp.MyForexHTTPClient","ref":"Forex.Feed.API.HTTP.html"},{"type":"behaviour","title":"Forex.Feed.Parser","doc":"This module defines the behaviour of the parser that will be used to parse\nthe XML response from the European Central Bank (ECB).","ref":"Forex.Feed.Parser.html"},{"type":"function","title":"Forex.Feed.Parser.parse_rates/1","doc":"","ref":"Forex.Feed.Parser.html#parse_rates/1"},{"type":"callback","title":"Forex.Feed.Parser.parse_rates/1","doc":"Parse the XML response body from the European Central Bank (ECB).","ref":"Forex.Feed.Parser.html#c:parse_rates/1"},{"type":"function","title":"Forex.Feed.Parser.parser_mod/0","doc":"","ref":"Forex.Feed.Parser.html#parser_mod/0"},{"type":"type","title":"Forex.Feed.Parser.rate/0","doc":"","ref":"Forex.Feed.Parser.html#t:rate/0"},{"type":"type","title":"Forex.Feed.Parser.rate_map/0","doc":"","ref":"Forex.Feed.Parser.html#t:rate_map/0"},{"type":"module","title":"Forex.Feed.Parser.ParserSweetXml","doc":"This module implements the Forex.Parser behaviour using the SweetXml library.","ref":"Forex.Feed.Parser.ParserSweetXml.html"},{"type":"module","title":"Forex.Fetcher","doc":"The `Forex.Fetcher` module is responsible for fetching the exchange rates\nfrom the cache or the feed on periodic intervals or on demand.\n\nThe exchange rates are fetched from the cache if the cache is enabled and\nthe cache is not stale. Otherwise, the exchange rates are fetched from the\nfeed and stored in the cache.\n\nBy default, the exchange rates are fetched from the feed every 12 hours as\nthe European Central Bank (ECB) updates the reference rates at around 16:00 CET\nevery working day. This can be configured by setting the `:schedular_interval`\noption in the `Forex` application environment, example, to fetch the rates\nevery 24 hours:\n\nTo configure the `Forex.Fetcher` module, the following options are available:\n\n* `use_cache` - A boolean value that determines if the cache should be used.\n  The default value is `true`.\n\n* `cache_module` - The cache module to use. The default value is `Forex.Cache.ETS`.\n\n* `schedular_interval` - The interval in milliseconds to fetch the exchange rates\n  from the feed. The default value is `12 hours`.\n\nTo start the `Forex.Fetcher` process, use the `start_link/1` or `start/1` functions,\nor add the `Forex.Fetcher.Supervisor` to the application supervision tree.","ref":"Forex.Fetcher.html"},{"type":"function","title":"Forex.Fetcher.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Forex.Fetcher.html#child_spec/1"},{"type":"function","title":"Forex.Fetcher.get/2","doc":"Fetch the respective exchange rates from the cache or the feed,\nbased on the `key` and the `opts`.\n\nThe `key` can be one of the following atoms:\n\n* `:current_rates` - Fetch the current exchange rates.\n* `:last_ninety_days_rates` - Fetch the exchange rates for the last 90 days.\n* `:historic_rates` - Fetch the exchange rates for a specific date.\n\nThe `opts` can be a keyword list with the module options, that is,\nthe options returned from the `Forex.Fetcher.options/1` function.","ref":"Forex.Fetcher.html#get/2"},{"type":"function","title":"Forex.Fetcher.options/1","doc":"Validate and return the options for the `Forex.Fetcher` module functions,\nusing default values if the options are not provided.","ref":"Forex.Fetcher.html#options/1"},{"type":"module","title":"Forex.Fetcher.Supervisor","doc":"The `Forex.Fetcher.Supervisor` module is responsible for supervising the `Forex.Fetcher`\nprocess, .ie., starting, stopping, and restarting the process.\n\nThe `Forex.Fetcher.Supervisor` accepts the following options:\n\n* `auto_start` - A boolean value that determines if the fetcher process should be started\n  automatically when the supervisor is started. The default value is `true`.","ref":"Forex.Fetcher.Supervisor.html"},{"type":"function","title":"Forex.Fetcher.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Forex.Fetcher.Supervisor.html#child_spec/1"},{"type":"function","title":"Forex.Fetcher.Supervisor.delete_fetcher/0","doc":"Delete the Forex exchange rate fetcher process from the supervisor.","ref":"Forex.Fetcher.Supervisor.html#delete_fetcher/0"},{"type":"function","title":"Forex.Fetcher.Supervisor.fetcher_initiated?/0","doc":"Check if the Forex exchange rate fetcher process has been initiated.","ref":"Forex.Fetcher.Supervisor.html#fetcher_initiated?/0"},{"type":"function","title":"Forex.Fetcher.Supervisor.fetcher_running?/0","doc":"Check if the Forex exchange rate fetcher process is running.","ref":"Forex.Fetcher.Supervisor.html#fetcher_running?/0"},{"type":"function","title":"Forex.Fetcher.Supervisor.fetcher_status/0","doc":"Get the status of the Forex exchange rate fetcher process.\nIf the process is running, it returns `:running`,\nif it has been initiated but not running, it returns `:stopped`,\notherwise, it returns `:not_started`.","ref":"Forex.Fetcher.Supervisor.html#fetcher_status/0"},{"type":"function","title":"Forex.Fetcher.Supervisor.options/1","doc":"","ref":"Forex.Fetcher.Supervisor.html#options/1"},{"type":"function","title":"Forex.Fetcher.Supervisor.restart_fetcher/0","doc":"Restart the stoped Forex exchange rate fetcher process.","ref":"Forex.Fetcher.Supervisor.html#restart_fetcher/0"},{"type":"function","title":"Forex.Fetcher.Supervisor.start_fetcher/1","doc":"Start the Forex exchange rate fetcher process.","ref":"Forex.Fetcher.Supervisor.html#start_fetcher/1"},{"type":"function","title":"Forex.Fetcher.Supervisor.stop_fetcher/0","doc":"Stop the Forex exchange rate fetcher process.","ref":"Forex.Fetcher.Supervisor.html#stop_fetcher/0"},{"type":"module","title":"Forex.Support","doc":"The `Forex.Support` module provides helper functions, for example, for\nformatting the exchange rates values.","ref":"Forex.Support.html"},{"type":"function","title":"Forex.Support.atomize_code/1","doc":"Conver the binary currency code to an atom representation.","ref":"Forex.Support.html#atomize_code/1"},{"type":"function","title":"Examples - Forex.Support.atomize_code/1","doc":"iex> Forex.Support.atomize_code(\"usd\")\n      :usd\n\n      iex> Forex.Support.atomize_code(:usd)\n      :usd\n\n      iex> Forex.Support.atomize_code(\"USD\")\n      :usd\n\n      iex> Forex.Support.atomize_code(:USD)\n      :usd\n\n      iex> Forex.Support.atomize_code(\"uSD\")\n      :usd\n\n      iex> Forex.Support.atomize_code(1)\n      ** (FunctionClauseError) no function clause matching in Forex.Support.atomize_code/1","ref":"Forex.Support.html#atomize_code/1-examples"},{"type":"function","title":"Forex.Support.cache_memory_usage/1","doc":"Cache memory usage in megabytes.\nUseful for debugging and monitoring the... cache memory usage.","ref":"Forex.Support.html#cache_memory_usage/1"},{"type":"function","title":"Examples - Forex.Support.cache_memory_usage/1","doc":"iex> r = Forex.Support.cache_memory_usage(:ets)\n    iex> r |> String.contains?(\"MB\")\n    true","ref":"Forex.Support.html#cache_memory_usage/1-examples"},{"type":"function","title":"Forex.Support.format_value/2","doc":"Format the rate value based on the `format` option","ref":"Forex.Support.html#format_value/2"},{"type":"function","title":"Examples - Forex.Support.format_value/2","doc":"iex> Forex.Support.format_value(\"1.2345\", :string)\n    \"1.2345\"\n\n    iex> Forex.Support.format_value(\"1.2345\", :decimal)\n    Decimal.new(\"1.2345\")\n\n    iex> Forex.Support.format_value(\"1.2345\", :decimal)\n    Decimal.new(\"1.2345\")\n\n    iex> Forex.Support.format_value(\"1.2345\", :string)\n    \"1.2345\"\n\n    iex> Forex.Support.format_value(1.2345, :decimal)\n    Decimal.new(\"1.2345\")\n\n    iex> Forex.Support.format_value(1.2345, :string)\n    \"1.2345\"\n\n    iex> Forex.Support.format_value(Decimal.new(\"1.2345\"), :decimal)\n    Decimal.new(\"1.2345\")\n\n    iex> Forex.Support.format_value(Decimal.new(\"1.2345\"), :string)\n    \"1.2345\"\n\n    iex> Forex.Support.format_value(1.2345, :number)\n    ** (Forex.FormatError) Invalid format value: number","ref":"Forex.Support.html#format_value/2-examples"},{"type":"function","title":"Forex.Support.map_date/1","doc":"Map the date to a `Date` struct\nor `nil` if the date cannot be parsed.","ref":"Forex.Support.html#map_date/1"},{"type":"function","title":"Examples - Forex.Support.map_date/1","doc":"iex> Forex.Support.map_date(\"2020-01-01\")\n    ~D[2020-01-01]\n\n    iex> Forex.Support.map_date(\"2020-01-01T00:00:00Z\")\n    ~D[2020-01-01]\n\n    iex> Forex.Support.map_date({1982, 2, 25})\n    ~D[1982-02-25]\n\n    iex> Forex.Support.map_date(~D[2020-01-01])\n    ~D[2020-01-01]\n\n    iex> Forex.Support.map_date(~U[2020-01-01T00:00:00Z])\n    ~D[2020-01-01]\n\n    iex> Forex.Support.map_date(\"2020-01-01T00:00:00\")\n    nil\n\n    iex> Forex.Support.map_date(\"1982-02-31T00:00:00Z\")\n    nil\n\n    iex> Forex.Support.map_date(1982)\n    nil","ref":"Forex.Support.html#map_date/1-examples"},{"type":"function","title":"Forex.Support.parse_date/1","doc":"Attempt to parse a date from a binary string in ISO 8601 format","ref":"Forex.Support.html#parse_date/1"},{"type":"function","title":"Examples - Forex.Support.parse_date/1","doc":"iex> Forex.Support.parse_date(\"2020-01-01\")\n    {:ok, ~D[2020-01-01]}\n\n    iex> Forex.Support.parse_date(\"2020-01-01T00:00:00Z\")\n    {:ok, ~D[2020-01-01]}\n\n    iex> Forex.Support.parse_date({1982, 2, 25})\n    {:ok, ~D[1982-02-25]}\n\n    iex> Forex.Support.parse_date(~D[2020-01-01])\n    {:ok, ~D[2020-01-01]}\n\n    iex> Forex.Support.parse_date(~U[2020-01-01T00:00:00Z])\n    {:ok, ~D[2020-01-01]}\n\n    iex> Forex.Support.parse_date(\"2020-01-01T00:00:00\")\n    {:error, :invalid_date}\n\n    iex> Forex.Support.parse_date(\"1982-02-31T00:00:00Z\")\n    {:error, :invalid_date}\n\n    iex> Forex.Support.parse_date(1982)\n    nil","ref":"Forex.Support.html#parse_date/1-examples"},{"type":"function","title":"Forex.Support.round_value/2","doc":"Round the rate value based on the `round` option","ref":"Forex.Support.html#round_value/2"},{"type":"function","title":"Examples - Forex.Support.round_value/2","doc":"iex> Forex.Support.round_value(1.2345, 2)\n      1.23\n\n      iex> Forex.Support.round_value(1.2345, 4)\n      1.2345\n\n      iex> Forex.Support.round_value(1.2345, 0)\n      1.0\n\n      iex> Forex.Support.round_value(1.2345, 15)\n      1.2345\n\n      iex> Forex.Support.round_value(Decimal.new(\"1.2345\"), 2)\n      Decimal.new(\"1.23\")\n\n      iex> Forex.Support.round_value(Decimal.new(\"1.2345\"), 4)\n      Decimal.new(\"1.2345\")\n\n      iex> Forex.Support.round_value(Decimal.new(\"1.2345\"), 0)\n      Decimal.new(\"1\")\n\n      iex> Forex.Support.round_value(\"1.2345\", 2)\n      \"1.23\"\n\n      iex> Forex.Support.round_value(\"1.2345\", 4)\n      \"1.2345\"\n\n      iex> Forex.Support.round_value(\"1.2345\", nil)\n      \"1.2345\"\n\n      iex> Forex.Support.round_value(nil, 2)\n      nil\n\n      iex> Forex.Support.round_value(1.2345, 16)\n      ** (FunctionClauseError) no function clause matching in Forex.Support.round_value/2","ref":"Forex.Support.html#round_value/2-examples"},{"type":"function","title":"Forex.Support.stringify_code/1","doc":"Convert the currency code to a default string representation (uppercase string).","ref":"Forex.Support.html#stringify_code/1"},{"type":"function","title":"Examples - Forex.Support.stringify_code/1","doc":"iex> Forex.Support.stringify_code(:usd)\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(\"usd\")\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(\"USD\")\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(:USD)\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(:usd)\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(\"usd\")\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(\"USD\")\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(:USD)\n    \"USD\"\n\n    iex> Forex.Support.stringify_code(1)\n    ** (FunctionClauseError) no function clause matching in Forex.Support.stringify_code/1","ref":"Forex.Support.html#stringify_code/1-examples"},{"type":"task","title":"mix forex","doc":"Prints Forex tasks and their information.\n\n    mix forex","ref":"Mix.Tasks.Forex.html"},{"type":"task","title":"mix forex.export.current","doc":"Fetch and export the current exchange rates from the\nEuropean Central Bank to a file.\n\n  mix forex.export.current","ref":"Mix.Tasks.Forex.Export.Current.html"},{"type":"task","title":"Examples - mix forex.export.current","doc":"* `mix forex.export.current`\n  * `mix forex.export.current --base USD`\n  * `mix forex.export.current --symbols USD,GBP`\n  * `mix forex.export.current --output priv/data/forex`","ref":"Mix.Tasks.Forex.Export.Current.html#module-examples"},{"type":"task","title":"Arguments - mix forex.export.current","doc":"* `--base`      - The base currency to use. Defaults to `EUR`.\n  * `--symbols`   - The currencies to fetch. Defaults to all currencies.\n  * `--output`    - The output directory. Defaults to `priv/data/forex`.\n  * `--help`      - Show this help message.","ref":"Mix.Tasks.Forex.Export.Current.html#module-arguments"},{"type":"task","title":"mix forex.export.historic","doc":"Fetch and export the historic exchange rates from the\nEuropean Central Bank to a file.\n\n  mix forex.export.historic","ref":"Mix.Tasks.Forex.Export.Historic.html"},{"type":"task","title":"Examples - mix forex.export.historic","doc":"* `mix forex.export.historic`\n  * `mix forex.export.historic --base USD`\n  * `mix forex.export.historic --symbols USD,GBP`\n  * `mix forex.export.historic --output priv/data/forex`","ref":"Mix.Tasks.Forex.Export.Historic.html#module-examples"},{"type":"task","title":"Arguments - mix forex.export.historic","doc":"* `--base`      - The base currency to use. Defaults to `EUR`.\n  * `--symbols`   - The currencies to fetch. Defaults to all currencies.\n  * `--output`    - The output directory. Defaults to `priv/data/forex`.\n  * `--help`      - Show this help message.","ref":"Mix.Tasks.Forex.Export.Historic.html#module-arguments"},{"type":"task","title":"mix forex.export.ninety","doc":"Fetch and export the last ninety days exchange rates\nfrom the European Central Bank to a file.\n\n  mix forex.export.ninety","ref":"Mix.Tasks.Forex.Export.Ninety.html"},{"type":"task","title":"Examples - mix forex.export.ninety","doc":"* `mix forex.export.ninety`\n  * `mix forex.export.ninety --base USD`\n  * `mix forex.export.ninety --symbols USD,GBP`\n  * `mix forex.export.ninety --output priv/data/forex`","ref":"Mix.Tasks.Forex.Export.Ninety.html#module-examples"},{"type":"task","title":"Arguments - mix forex.export.ninety","doc":"* `--base`      - The base currency to use. Defaults to `EUR`.\n  * `--symbols`   - The currencies to fetch. Defaults to all currencies.\n  * `--output`    - The output directory. Defaults to `priv/data/forex`.\n  * `--help`      - Show this help message.","ref":"Mix.Tasks.Forex.Export.Ninety.html#module-arguments"},{"type":"exception","title":"Forex.CurrencyError","doc":"Exception for currency errors.","ref":"Forex.CurrencyError.html"},{"type":"exception","title":"Forex.DateError","doc":"Exception for date errors.","ref":"Forex.DateError.html"},{"type":"exception","title":"Forex.FeedError","doc":"Exception for feed errors.","ref":"Forex.FeedError.html"},{"type":"exception","title":"Forex.FormatError","doc":"Exception for format errors.","ref":"Forex.FormatError.html"},{"type":"extras","title":"Forex","doc":"# Forex\n\n`Forex` is a simple Elixir library that serves as a wrapper to the\n  foreign exchange reference rates provided by the European Central Bank.\n\n  > [!NOTE]\n  >","ref":"readme.html"},{"type":"extras","title":"From the [European Central Bank](https://www.ecb.europa.eu/stats/policy_and_exchange_rates/euro_reference_exchange_rates/html/index.en.html) - Forex","doc":">\n  > The reference rates are usually updated at around **16:00 CET** every working day, except on\n  > [TARGET closing days](https://www.ecb.europa.eu/ecb/contacts/working-hours/html/index.en.html).\n  >\n  > They are based on the daily concertation procedure between central banks across Europe,\n  > which normally takes place around 14:10 CET. The reference rates are published for\n  > information purposes only. Using the rates for transaction\n  > purposes is _strongly discouraged_.","ref":"readme.html#from-the-european-central-bank-https-www-ecb-europa-eu-stats-policy_and_exchange_rates-euro_reference_exchange_rates-html-index-en-html"},{"type":"extras","title":"Motivation - Forex","doc":"Even though there are other libraries in the Elixir ecosystem that provide\n  similar functionality (example: `ex_money`), `Forex` was created with the intent\n  of providing access to currency exchange rates for projects that want to self-host\n  the data and not rely on third-party paid services in a simple and straightforward\n  manner. No API keys, no authentication, no rate limits, just a simple Elixir library\n  that fetches the data from the European Central Bank and caches it for later use.","ref":"readme.html#motivation"},{"type":"extras","title":"Options - Forex","doc":"* `:base` - The base currency to convert the rates to. The default currency base is `:eur`.\n\n  * `:format` - The format of the rate value. Supported values are `:decimal` and `:string`.\n    The default is `:decimal`.\n\n  * `:round` - The number of decimal places to round the rate value to. The default is `5`.\n\n  * `:symbols` - A list of currency codes (atoms or strings) to filter the rates by.\n    The default is `nil`, which means all available currencies will be returned.\n\n  * `:keys` - The format of the keys in the rate map. Supported values are `:strings` and `:atoms`.\n    The default is `:atoms`.\n\n  * `:use_cache` - A boolean value to enable or disable the cache. To enable the cache check the\n    usage section docs for detailed instructions. The default is `true`.\n\n  * `:feed_fn` - An `mfa` tuple that can be used to fetch the exchange rates from a custom feed.\n    This option is mostly used for testing purposes. The default is `nil`, which means the\n    default feed will be used.","ref":"readme.html#options"},{"type":"extras","title":"Usage - Forex","doc":"By default the `base` currency is the Euro (EUR), the same as the European Central Bank,\n  but you change the base currency by passing the `base` option to the relevant functions.\n\n  To fetch the latest exchange rates, you can use the `current_rates/1` function:\n\n  ```elixir\n  iex> Forex.current_rates()\n  {:ok,\n    %{\n      base: :eur,\n      date: ~D[2025-03-12],\n      rates: %{\n        usd: Decimal.new(\"1.1234\"),\n        jpy: Decimal.new(\"120.1234\"),\n        ...\n        zar: Decimal.new(\"24.1442\")\n      }}\n    }\n  ```\n\n  To fetch the exchange rates for the last ninety days, you can use the `last_ninety_days_rates/1` function:\n\n  ```elixir\n  iex> Forex.last_ninety_days_rates()\n  {:ok,\n    [\n      %{\n        date: ~D[2025-03-12],\n        base: :eur,\n        rates: %{\n          usd: Decimal.new(\"1.1234\"),\n          jpy: Decimal.new(\"120.1234\"),\n          ...\n          zar: Decimal.new(\"24.1442\")\n        }\n      },\n      ...\n    ]}\n  ```\n\n  To fetch the historic exchange rates (for any working day since 4 January 1999),\n  you can use the `historic_rates/1` function:\n\n  ```elixir\n  iex> Forex.historic_rates()\n  {:ok,\n    [\n      %{\n        date: ~D[2025-03-12],\n        base: :eur,\n        rates: %{\n          usd: Decimal.new(\"1.1234\"),\n          jpy: Decimal.new(\"120.1234\"),\n          ...\n          zar: Decimal.new(\"24.1442\")\n        }\n      },\n      ...\n    ]}\n  ```\n\n  To fetch the exchange rates for a specific date, you can use the `get_historic_rate/2` function:\n\n  ```elixir\n  iex> Forex.get_historic_rate(~D[2025-02-25])\n  {:ok,\n    [\n      %{\n        date: ~D[2025-03-12],\n        base: :eur,\n        rates: %{\n          usd: Decimal.new(\"1.1234\"),\n          jpy: Decimal.new(\"120.1234\"),\n          ...\n          zar: Decimal.new(\"24.1442\")\n        }\n      },\n      ...\n    ]}\n  ```\n\n  To fetch the exchange rates between two dates, you can use the `get_historic_rates_between/3` function:\n\n  ```elixir\n  iex> Forex.get_historic_rates_between(~D[2025-02-25], ~D[2025-02-28])\n\n  {:ok,\n    [\n      %{\n        date: ~D[2025-03-12],\n        base: :eur,\n        rates: %{\n          usd: Decimal.new(\"1.1234\"),\n          jpy: Decimal.new(\"120.1234\"),\n          ...\n          zar: Decimal.new(\"24.1442\")\n        }\n      },\n      ...\n    ]}\n  ```\n\n  To convert an amount from one currency to another, you can use the `exchange/4` function:\n\n  ```elixir\n  iex> Forex.exchange(100, \"USD\", \"EUR\")\n  {:ok, Decimal.new(\"91.86100\")}\n\n  iex>  Forex.exchange(420, :eur, :gbp)\n  {:ok, Decimal.new(\"353.12760\")}\n  ```\n\n  To list all available currencies from the European Central Bank,\n  you can use the `available_currencies/1` function:\n\n  ```elixir\n  iex> Forex.available_currencies()\n  [:try, :eur, :aud, :bgn, :brl, ...]\n  ```\n\n\nFull documentation can be found at https://hexdocs.pm/forex.","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Forex","doc":"The package can be installed by adding `forex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:forex, \"~> 0.1.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License - Forex","doc":"This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Change Log","doc":"# Change Log\n\nAll notable changes to this project will be documented in this file.\nSee [Conventional Commits](Https://conventionalcommits.org) for commit guidelines.\n\n<!-- changelog -->\n\n## [v0.1.1](https://github.com/greven/forex.git/compare/v0.1.1...v0.1.1) (2025-03-19)","ref":"changelog.html"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Nuno Freire\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}